@@ -7,6 +7,7 @@ from typing import Callable
 from django.db import models as django_models
 from .utils import check_types, check_classes, get_ids_from_untyped_data
 from .cache import default_cache_func
+from time import sleep
 
 
 class RedisField:
@@ -482,13 +483,18 @@ class RedisRoot:
                                 else:
                                     real_value = None
                                 value = real_value
+                                allowed_redis_params[redis_field_param_name] = value
                             elif django_field_param_name == 'remote_field':
                                 redis_field_param_name = 'model'
-                                print(django_field, django_field.__class__.__name__, value)
                                 if value is not None:
                                     value = value.model
+                                    print(django_field_param_name, value)
                                     value = get_or_create_redis_model_from_django_model(value, redis_root)
-                            allowed_redis_params[redis_field_param_name] = value
+                                    print(django_field_param_name, value)
+                                    if value is not None:
+                                        allowed_redis_params[redis_field_param_name] = value
+                            else:
+                                allowed_redis_params[redis_field_param_name] = value
                     return allowed_redis_params
 
                 field_mapping = {
